DirectSelect class

Inheritance

Constructors

DirectSelect({required List<Widget> items, required ValueChanged<int?> onSelectedItemChanged, required double itemExtent, required Widget child, int selectedIndex = 0, DirectSelectMode mode = DirectSelectMode.drag, double itemMagnification = 1.15, Color backgroundColor = Colors.white, Color selectionColor = Colors.black12, Key? key})
const

Properties

backgroundColor → Color
Color of the background, Colors.white by default.
final
child → Widget
Widget child you'll tap to display the Selection List.
final
hashCode → int
The hash code for this object.
no setterinherited
itemExtent → double
Height of each Item of the Selection List.
final
itemMagnification → double
Amount of magnification when showing the selected item in the overlay.
final
items → List<Widget>
List of Widgets you'll display after you tap the child.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mode → DirectSelectMode
The preferred method to engage this widget.
final
onSelectedItemChanged → ValueChanged<int?>
Listener when you select any item from the Selection List.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedIndex → int
Selected index of your selection list.
final
selectionColor → Color
Color of the selection background, Colors.black12 by default.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited